@@ -1,7 +1,10 @@
+from typing import List
+
+from weaverbird.backends.mongo_translator.steps.types import MongoStep
 from weaverbird.pipeline.steps import ArgmaxStep
 
 
-def translate_argmax(step: ArgmaxStep) -> list:
+def translate_argmax(step: ArgmaxStep) -> List[MongoStep]:
     return [
         {
             '$group': {
