@@ -13,6 +13,7 @@ from .custom import CustomStep
 from .customsql import CustomSqlStep, CustomSqlStepWithVariables
 from .date_extract import DateExtractStep, DateExtractStepWithVariable
 from .delete import DeleteStep
+from .dissolve import DissolveStep
 from .domain import DomainStep
 from .duplicate import DuplicateStep
 from .duration import DurationStep, DurationStepWithVariable
@@ -21,6 +22,7 @@ from .fillna import FillnaStep, FillnaStepWithVariable
 from .filter import FilterStep, FilterStepWithVariables
 from .formula import FormulaStep, FormulaStepWithVariable
 from .fromdate import FromdateStep
+from .hierarchy import HierarchyStep
 from .ifthenelse import IfthenelseStep, IfThenElseStepWithVariables
 from .join import JoinStep, JoinStepWithVariable
 from .lowercase import LowercaseStep
@@ -32,6 +34,7 @@ from .rename import RenameStep, RenameStepWithVariable
 from .replace import ReplaceStep, ReplaceStepWithVariable
 from .rollup import RollupStep, RollupStepWithVariable
 from .select import SelectStep
+from .simplify import SimplifyStep
 from .sort import SortStep
 from .split import SplitStep, SplitStepWithVariable
 from .statistics import StatisticsStep
