@@ -1,6 +1,4 @@
-from typing import List
-
-from pydantic import Field
+from typing import List, Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -9,7 +7,7 @@ from .utils.combination import PipelineOrDomainNameOrReference
 
 
 class AppendStep(BaseStep):
-    name = Field('append', const=True)
+    name: Literal['append'] = 'append'
     pipelines: List[PipelineOrDomainNameOrReference]
 
 
