@@ -1,14 +1,13 @@
-from pydantic import Field
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
 
 
 class CustomSqlStep(BaseStep):
-    name = Field('customsql', const=True)
+    name: Literal['customsql'] = 'customsql'
     query: str
 
 
 class CustomSqlStepWithVariables(CustomSqlStep, StepWithVariablesMixin):
-    name = Field('customsql', const=True)
-    query: str
+    ...
