@@ -1,10 +1,10 @@
-from pydantic import Field
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.types import ColumnName
 
 
 class DuplicateStep(BaseStep):
-    name = Field('duplicate', const=True)
+    name: Literal['duplicate'] = 'duplicate'
     column: ColumnName
     new_column_name: ColumnName
